//######################################################################################################################
// #ICONOGRAPHY#

// default font file generated by gulp
@font-face {
    font-family: "<%= fontName %>";
    src: url("<%= fontPath %><%= fontName %>.eot?v=3.2.0");
    src: url("<%= fontPath %><%= fontName %>.eot?v=3.2.0#iefix") format("eot"),
         url("<%= fontPath %><%= fontName %>.woff2?v=3.2.0") format("woff2"),
         url("<%= fontPath %><%= fontName %>.woff?v=3.2.0") format("woff"),
         url("<%= fontPath %><%= fontName %>.ttf?v=3.2.0") format("truetype"),
         url("<%= fontPath %><%= fontName %>.svg?v=3.2.0#<%= fontName %>") format("svg");
    font-weight: normal;
    font-style: normal;
}

%icon {
    display: inline-block;
    font: normal normal normal 14px/1 <%= fontName %>;
    font-size: inherit;
    text-rendering: auto;
    transform: translate(0, 0);
    -webkit-font-smoothing: antialiased;
    -moz-osx-font-smoothing: grayscale;
}

@function icon-char($filename) {
    $char: "";
<% _.each(glyphs, function(glyph) { %>
    @if $filename == <%= glyph.fileName %> {
        $char: "<%= glyph.codePoint %>";
    }<% }); %>

    @return $char;
}

.cms-icon {
    @extend %icon;
}
@mixin icon($filename, $insert: before) {
    &:#{$insert} {
        content: #{"\"\\"}#{icon-char($filename) + "\""};
    }
}

// #####################################################################################################################
// #ICONS:start#
// use unicode characters for accessibility reasons and use aria-hidden="true" for decorative icons
// DOCS: http://filamentgroup.com/lab/bulletproof_icon_fonts.html
<% _.each(glyphs, function(glyph) { %>
.cms-icon-<%= glyph.fileName %> {
    @include icon(<%= glyph.fileName %>);
}
<% }); %>
