{% load i18n %}
<meta name="djangocms_version" content="{{ cms_version }}">
<meta name="djangocms_version_check_type" content="{{ cms_version_check_type }}">
<script type="text/template" id="cms-update-notification">
    <div class="cms-update-message" hidden>
        {% autoescape off %}
            {% blocktrans with version='<strong>'|add:cms_version|add:'</strong>' latest='<strong class="js-latest-version"></strong>' release_link_before='<a class="js-release-notes-link" target="_blank" href="">' release_link_after='</a>' %}
                There is a django CMS upgrade available. You are using: {{ version }}, new version is: {{ latest }}.
                {{ release_link_before }}Read the release notes.{{ release_link_after }}
            {% endblocktrans %}
        {% endautoescape %}
        <a href="#" class="close">&times;</a>
    </div>
</script>
