//  html5doctor.com Reset Stylesheet (Eric Meyer's Reset Reloaded + HTML5 baseline)
//  v1.6.1 2010-09-17 | Authors: Eric Meyer & Richard Clark
//  html5doctor.com/html-5-reset-stylesheet/

@mixin html5-boilerplate-reset {
    html,
    body,
    div,
    span,
    object,
    iframe,
    h1,
    h2,
    h3,
    h4,
    h5,
    h6,
    p,
    blockquote,
    pre,
    abbr,
    address,
    cite,
    code,
    del,
    dfn,
    em,
    img,
    ins,
    kbd,
    q,
    samp,
    small,
    strong,
    sub,
    sup,
    var,
    b,
    i,
    dl,
    dt,
    dd,
    ol,
    ul,
    li,
    fieldset,
    form,
    label,
    legend,
    table,
    caption,
    tbody,
    tfoot,
    thead,
    tr,
    th,
    td,
    article,
    aside,
    canvas,
    details,
    figcaption,
    figure,
    footer,
    header,
    hgroup,
    menu,
    nav,
    section,
    summary,
    time,
    mark,
    audio,
    video {
        font-size: $font-size-normal;
        line-height: $line-height-normal;
        vertical-align: baseline;
        margin: 0;
        padding: 0;
        border: 0;
    }

    article,
    aside,
    details,
    figcaption,
    figure,
    footer,
    header,
    hgroup,
    menu,
    nav,
    section {
        display: block;
    }

    blockquote,
    q {
        quotes: none;
    }

    blockquote:before,
    blockquote:after,
    q:before,
    q:after {
        content: "";
        content: none;
    }

    ins {
        color: $black;
        text-decoration: none;
        background-color: #ff9;
    }

    mark {
        color: $black;
        font-weight: bold; 
        font-style: italic;
        background-color: #ff9;
    }

    del {
        text-decoration: line-through;
    }

    abbr[title],
    dfn[title] {
        border-bottom: 1px dotted;
        cursor: help;
    }

    table {
        border-spacing: 0;
        border-collapse: collapse;
    }

    hr {
        display: block;
        height: 1px;
        margin: 1em 0;
        padding: 0;
        border: 0;
        border-top: 1px solid #ccc;
    }
}
