//##############################################################################
// LOGIN

body.login.djangocms-admin-style {
    background: none !important;
    background-color: $gray-lightest !important;
    #container {
        @include box();
        width: 35.5% !important;
        min-width: 320px !important;
        margin-top: 165px;
        border: none;
        box-shadow: $base-box-shadow;
        background-color: $white !important;
        overflow: visible;
        #content-main {
            float: none;
        }
        #header {
            position: static;
            background: none;
            box-shadow: none;
            padding: 0;
            #branding h1 {
                display: block;
                float: none;
                color: $gray-darkest;
                font-size: $font-size-large;
                line-height: inherit;
                height: auto;
                margin: 50px 20px 0 !important;
            }
        }
        #header-logo{
            float: none;
            text-align: center;
            margin-top: -70px;
            a:before {
                font-size: 35px;
            }
        }
        #header-btn,
        #header-logo h1,
        #site-name {
            display: none;
        }
        #content {
            margin: 0 !important;
            padding: 17px 20px 30px !important;
            .errornote {
                width: calc(100% - 20px) !important;
            }
            #content-main {
                form {
                    margin: 0 !important;
                    padding: 0;
                    box-shadow: none;
                }
                .form-row {
                    padding-bottom: 10px;
                    label {
                        float: left !important;
                        font-size: $font-size-normal;
                        line-height: $line-height-normal;
                    }
                    input {
                        color: $gray-darkest !important;
                        font-size: $font-size-small;
                        width: 100% !important;
                        padding: 10px;
                    }
                    #id_username,
                    #id_password {
                        // resets password field background color on login screen #175, #151
                        background-color: $white;
                        // resets margin top on login screen which is used in general forms #255
                        margin-top: 0 !important;
                    }
                }
                .submit-row {
                    float: right;
                    width: 100%;
                    padding: 0 !important;
                    margin-top: 10px;
                    margin-right: 0;
                    background: none;
                    border-top: 0;
                    input,
                    input[type="submit"] {
                        @include button-variant($btn-action-color, $btn-action-bgcolor, $btn-action-border, true);
                        float: right;
                        width: auto !important;
                        padding: 10px 20px !important;
                        background-image: none;
                    }
                    label {
                        display: none;
                    }
                }
            }
        }
        #footer {
            display: none;
        }
    }
}
