//##############################################################################
// CMS PLACEHOLDERS

.plugin-holder {
    background: transparent url("../img/pluginlist-holder-bg.png") repeat-y !important;
    h2 {
        margin-bottom: 0 !important;
    }
    .plugin-list-holder {
        width: 285px;
        .text {
            width: 240px;
        }
        ul.plugin-list li.active {
            background: url("../img/bg-pattern-light.jpg") $gray-lighter repeat;
            &:hover {
                background: white url("../../cms/images/sitemap-li-bg.jpg") repeat-x 0 -100px;
            }
        }
    }
}
.plugin-editor > iframe {
    min-height: 600px;
}
