module.exports = {
    "env": {
        "node": true
    },
    "globals": {
        "$": true,
        "module": true,
        "process": true,
        "it": true,
        "CMS": true,
        "expect": true,
        "jasmine": true,
        "describe": true,
        "casper": true,
        "beforeEach": true,
        "afterEach": true,
        "beforeAll": true,
        "afterAll": true,
        "spyOn": true,
        "spyOnEvent": true,
        "fixture": true,
        "pending": true
    },
    "rules": {
        "no-magic-numbers": 0,
        "max-nested-callbacks": [2, 8],
        "newline-after-var": 0,
        "strict": [2, "global"]
    }
};
