//##############################################################################
// SIDEFRAME

.cms-admin-sideframe {
    #header {
        // because there is already toolbar visible, header in side frame has to be hidden to not be visible when scrolling on tablet #245
        display: none;
    }
    #container .breadcrumbs + .messagelist + #content,
    #container .breadcrumbs + #content {
       margin-left: 3% !important;
    }
    .breadcrumbs {
        // removes padding left to align breadcrumbs #242
        padding-left: 0 !important;
    }
    &.cms-debug #container  .breadcrumbs {
        padding-top: $breadcrumb-padding + $toolbar-debug-height !important;
    }
    #content {
        // updates content margin top because of breadcrumbs #242
        margin-top: 117px !important;
    }
    &.cms-debug #content {
        margin-top: 117px + $toolbar-debug-height !important;
    }
    ul.messagelist {
        margin-top: 46px !important;
    }
}
